@@ -1,5 +1,4 @@
 from autoconf import conf
-from autoarray.structures import grids
 from autolens import exc
 from autolens.fit import fit_point_source
 
@@ -94,7 +93,10 @@ class SettingsLens:
 
     def check_einstein_radius_with_threshold_via_tracer(self, tracer, grid):
 
-        if self.einstein_radius_estimate is None:
+        if (
+            self.einstein_radius_estimate is None
+            or self.auto_einstein_radius_factor is None
+        ):
             return
 
         if self.einstein_radius_count > self.auto_einstein_radius_count:
