@@ -5,7 +5,7 @@ from autoarray.exc import PixelizationException, InversionException, GridExcepti
 from autofit.exc import FitException
 from autogalaxy.pipeline.phase.dataset import analysis as ag_analysis
 from autolens.fit import fit
-from autolens.pipeline import visualizer
+from autolens.pipeline import visualizer as vis
 from autolens.pipeline.phase.dataset import analysis as analysis_dataset
 from autogalaxy.pipeline.phase.imaging.analysis import Attributes as AgAttributes
 
@@ -23,10 +23,6 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
             results=results,
         )
 
-        self.visualizer = visualizer.PhaseImagingVisualizer(
-            masked_dataset=masked_imaging
-        )
-
     @property
     def masked_imaging(self):
         return self.masked_dataset
@@ -53,6 +49,10 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
             tracer=tracer, positions=self.masked_dataset.positions
         )
 
+        self.settings.settings_lens.check_einstein_radius_with_threshold_via_tracer(
+            tracer=tracer, grid=self.masked_dataset.grid
+        )
+
         hyper_image_sky = self.hyper_image_sky_for_instance(instance=instance)
 
         hyper_background_noise = self.hyper_background_noise_for_instance(
@@ -81,25 +81,29 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
 
             for i in range(self.settings.settings_lens.stochastic_likelihood_resamples):
 
-                settings_pixelization = copy.deepcopy(self.settings.settings_pixelization)
+                settings_pixelization = copy.deepcopy(
+                    self.settings.settings_pixelization
+                )
 
                 settings_pixelization.kmeans_seed = i
-        #       settings_pixelization.is_stochastic = True
+                #       settings_pixelization.is_stochastic = True
 
                 try:
-                    figures_of_merit.append(fit.FitImaging(
-                        masked_imaging=self.masked_dataset,
-                        tracer=tracer,
-                        hyper_image_sky=hyper_image_sky,
-                        hyper_background_noise=hyper_background_noise,
-                        settings_pixelization=settings_pixelization,
-                        settings_inversion=self.settings.settings_inversion,
-                    ).log_evidence)
+                    figures_of_merit.append(
+                        fit.FitImaging(
+                            masked_imaging=self.masked_dataset,
+                            tracer=tracer,
+                            hyper_image_sky=hyper_image_sky,
+                            hyper_background_noise=hyper_background_noise,
+                            settings_pixelization=settings_pixelization,
+                            settings_inversion=self.settings.settings_inversion,
+                        ).log_evidence
+                    )
                 except (
-                        PixelizationException,
-                        InversionException,
-                        GridException,
-                        OverflowError,
+                    PixelizationException,
+                    InversionException,
+                    GridException,
+                    OverflowError,
                 ) as e:
                     raise FitException from e
 
@@ -170,8 +174,6 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
 
     def visualize(self, paths: af.Paths, instance, during_analysis):
 
-        self.visualizer.visualize_imaging(paths=paths)
-
         instance = self.associate_hyper_images(instance=instance)
         tracer = self.tracer_for_instance(instance=instance)
         hyper_image_sky = self.hyper_image_sky_for_instance(instance=instance)
@@ -185,45 +187,25 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
             hyper_background_noise=hyper_background_noise,
         )
 
-        if tracer.has_mass_profile:
+        visualizer = vis.Visualizer(visualize_path=paths.image_path)
 
-            try:
-
-                visualizer = self.visualizer.new_visualizer_with_preloaded_critical_curves_and_caustics(
-                    preloaded_critical_curves=tracer.critical_curves,
-                    preloaded_caustics=tracer.caustics,
-                )
-
-            except (Exception, IndexError, ValueError):
-
-                visualizer = self.visualizer
-
-        else:
-
-            visualizer = self.visualizer
-
-        try:
-            visualizer.visualize_ray_tracing(
-                paths=paths, tracer=fit.tracer, during_analysis=during_analysis
+        visualizer.visualize_imaging(imaging=self.masked_imaging.imaging)
+        visualizer.visualize_fit_imaging(fit=fit, during_analysis=during_analysis)
+        visualizer.visualize_tracer(
+            tracer=fit.tracer, grid=fit.grid, during_analysis=during_analysis
+        )
+        if fit.inversion is not None:
+            visualizer.visualize_inversion(
+                inversion=fit.inversion, during_analysis=during_analysis
             )
-        except Exception:
-            pass
 
-        try:
-            visualizer.visualize_fit(
-                paths=paths, fit=fit, during_analysis=during_analysis
-            )
-        except Exception:
-            pass
-
-        self.visualizer.visualize_hyper_images(
-            paths=paths,
+        visualizer.visualize_hyper_images(
             hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
             hyper_model_image=self.hyper_model_image,
-            contribution_maps_of_galaxies=tracer.contribution_maps_of_planes,
+            tracer=tracer,
         )
 
-        if self.visualizer.plot_fit_no_hyper:
+        if visualizer.plot_fit_no_hyper:
 
             fit = self.masked_imaging_fit_for_tracer(
                 tracer=tracer,
@@ -232,15 +214,9 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
                 use_hyper_scalings=False,
             )
 
-            try:
-                visualizer.visualize_fit(
-                    paths=paths,
-                    fit=fit,
-                    during_analysis=during_analysis,
-                    subfolders="fit_no_hyper",
-                )
-            except Exception:
-                pass
+            visualizer.visualize_fit_imaging(
+                fit=fit, during_analysis=during_analysis, subfolders="fit_no_hyper"
+            )
 
     def make_attributes(self):
         return Attributes(
