@@ -1,3 +1,4 @@
+from os import path
 import autofit as af
 from astropy import cosmology as cosmo
 from autogalaxy.galaxy import fit_galaxy
@@ -7,16 +8,16 @@ from autolens.pipeline import visualizer
 
 
 class Analysis(af.Analysis):
-    def __init__(self, cosmology, results, image_path):
+    def __init__(self, cosmology, results):
         self.cosmology = cosmology
         self.results = results
-        self.visualizer = visualizer.PhaseGalaxyVisualizer(image_path)
+        self.visualizer = visualizer.PhaseGalaxyVisualizer()
 
 
 # noinspection PyAbstractClass
 class AnalysisSingle(Analysis):
-    def __init__(self, galaxy_data, cosmology, image_path: str, results=None):
-        super().__init__(cosmology=cosmology, image_path=image_path, results=results)
+    def __init__(self, galaxy_data, cosmology, results=None):
+        super().__init__(cosmology=cosmology, results=results)
 
         self.galaxy_data = galaxy_data
 
@@ -24,7 +25,7 @@ class AnalysisSingle(Analysis):
         fit = self.fit_for_instance(instance=instance)
         return fit.figure_of_merit
 
-    def visualize(self, instance, during_analysis):
+    def visualize(self, paths, instance, during_analysis):
         fit = self.fit_for_instance(instance=instance)
 
         self.visualizer.plot_galaxy_fit_subplot(fit)
@@ -40,7 +41,7 @@ class AnalysisSingle(Analysis):
 
             if self.visualizer.plot_ray_tracing_all_at_end_fits:
                 self.visualizer.plot_fit_individuals(
-                    fit=fit, plot_all=True, image_format="fits", path_suffix="/fits/"
+                    fit=fit, plot_all=True, image_format="fits", path_suffix="fits"
                 )
 
         return fit
@@ -68,10 +69,8 @@ class AnalysisSingle(Analysis):
 
 # noinspection PyAbstractClass
 class AnalysisDeflections(Analysis):
-    def __init__(
-        self, galaxy_data_y, galaxy_data_x, cosmology, image_path, results=None
-    ):
-        super().__init__(cosmology=cosmology, image_path=image_path, results=results)
+    def __init__(self, galaxy_data_y, galaxy_data_x, cosmology, results=None):
+        super().__init__(cosmology=cosmology, results=results)
 
         self.galaxy_data_y = galaxy_data_y
         self.galaxy_data_x = galaxy_data_x
@@ -80,32 +79,38 @@ class AnalysisDeflections(Analysis):
         fit_y, fit_x = self.fit_for_instance(instance=instance)
         return fit_y.figure_of_merit + fit_x.figure_of_merit
 
-    def visualize(self, instance, during_analysis):
+    def visualize(self, paths, instance, during_analysis):
 
         fit_y, fit_x = self.fit_for_instance(instance=instance)
 
         if self.visualizer.plot_subplot_galaxy_fit:
-            self.visualizer.plot_galaxy_fit_subplot(fit_y, path_suffix="/fit_y_")
-            self.visualizer.plot_galaxy_fit_subplot(fit_x, path_suffix="/fit_x_")
+            self.visualizer.plot_galaxy_fit_subplot(fit_y, path_suffix="fit_y_")
+            self.visualizer.plot_galaxy_fit_subplot(fit_x, path_suffix="fit_x_")
 
         if during_analysis:
-            self.visualizer.plot_fit_individuals(fit_y, path_suffix="/fit_y")
-            self.visualizer.plot_fit_individuals(fit_x, path_suffix="/fit_x")
+            self.visualizer.plot_fit_individuals(fit_y, path_suffix="fit_y")
+            self.visualizer.plot_fit_individuals(fit_x, path_suffix="fit_x")
         else:
             if self.visualizer.plot_ray_tracing_all_at_end_png:
                 self.visualizer.plot_fit_individuals(
-                    fit_y, path_suffix="/fits/fit_y", plot_all=True
+                    fit_y, path_suffix=path.join("fits", "fit_y"), plot_all=True
                 )
                 self.visualizer.plot_fit_individuals(
-                    fit_x, path_suffix="/fits/fit_x", plot_all=True
+                    fit_x, path_suffix=path.join("fits", "fit_x"), plot_all=True
                 )
 
             if self.visualizer.plot_ray_tracing_all_at_end_fits:
                 self.visualizer.plot_fit_individuals(
-                    fit_y, path_suffix="/fits/fit_y", plot_all=True, image_format="fits"
+                    fit_y,
+                    path_suffix=path.join("fits", "fit_y"),
+                    plot_all=True,
+                    image_format="fits",
                 )
                 self.visualizer.plot_fit_individuals(
-                    fit_x, path_suffix="/fits/fit_x", plot_all=True, image_format="fits"
+                    fit_x,
+                    path_suffix=path.join("fits", "fit_x"),
+                    plot_all=True,
+                    image_format="fits",
                 )
 
         return fit_y, fit_x
@@ -228,10 +233,7 @@ class PhaseGalaxy(abstract.AbstractPhase):
             )
 
             return AnalysisSingle(
-                galaxy_data=galaxy_data,
-                cosmology=self.cosmology,
-                image_path=self.search.paths.image_path,
-                results=results,
+                galaxy_data=galaxy_data, cosmology=self.cosmology, results=results
             )
 
         elif self.use_deflections:
@@ -262,7 +264,6 @@ class PhaseGalaxy(abstract.AbstractPhase):
                 galaxy_data_y=galaxy_data_y,
                 galaxy_data_x=galaxy_data_x,
                 cosmology=self.cosmology,
-                image_path=self.search.paths.image_path,
                 results=results,
             )
 
